@@ -4,32 +4,27 @@ use downcast_rs::{impl_downcast, Downcast};
 use ross_protocol::convert_packet::ConvertPacketError;
 use ross_protocol::packet::Packet;
 
+use crate::serializer::Serialize;
 use crate::ExtractorValue;
 
-mod none_extractor;
-pub use none_extractor::*;
+mod none;
+pub use none::*;
 
-mod event_code_extractor;
-pub use event_code_extractor::*;
+mod packet;
+pub use packet::*;
 
-mod packet_extractor;
-pub use packet_extractor::*;
+mod event;
+pub use event::*;
 
-mod event_producer_address_extractor;
-pub use event_producer_address_extractor::*;
+mod message;
+pub use message::*;
 
-mod message_code_extractor;
-pub use message_code_extractor::*;
-
-mod message_value_extractor;
-pub use message_value_extractor::*;
-
-mod button_index_extractor;
-pub use button_index_extractor::*;
+mod button;
+pub use button::*;
 
 pub const NONE_EXTRACTOR_CODE: u16 = 0x0000;
-pub const EVENT_CODE_EXTRACTOR_CODE: u16 = 0x0001;
-pub const PACKET_EXTRACTOR_CODE: u16 = 0x0002;
+pub const PACKET_EXTRACTOR_CODE: u16 = 0x0001;
+pub const EVENT_CODE_EXTRACTOR_CODE: u16 = 0x0002;
 pub const EVENT_PRODUCER_ADDRESS_EXTRACTOR_CODE: u16 = 0x0003;
 pub const MESSAGE_CODE_EXTRACTOR_CODE: u16 = 0x0004;
 pub const MESSAGE_VALUE_EXTRACTOR_CODE: u16 = 0x0005;
@@ -42,8 +37,9 @@ pub enum ExtractorError {
     ConvertValueError,
 }
 
-pub trait Extractor: Downcast + Debug {
+pub trait Extractor: Downcast + Debug + Serialize {
     fn extract<'a>(&self, packet: &'a Packet) -> Result<ExtractorValue<'a>, ExtractorError>;
+    fn get_code(&self) -> u16;
 }
 
 impl_downcast!(Extractor);
